# eric7.PluginManager.PluginUtilities

Module implementing common utility functions needed for plugin management.

### Global Attributes

None

### Classes

None

### Functions

getPluginHeaderEntry | Function to get an entry of the plugin header.
hasPluginHeaderEntry | Function to check, if the plugin header contains the given entry.

## getPluginHeaderEntry

getPluginHeaderEntry(plugin, entry, default)

Function to get an entry of the plugin header.

plugin (module)
  reference to the plugin module
entry (str)
  name of the entry
default (Any)
  value to be returned if the entry does not exist

Return:
  requested value

Return Type:
  Any

Up

## hasPluginHeaderEntry

hasPluginHeaderEntry(plugin, entry)

Function to check, if the plugin header contains the given entry.

plugin (module)
  reference to the plugin module
entry (str)
  name of the entry

Return:
  flag indicating the existence

Return Type:
  bool

Up